@@ -18,10 +18,3 @@ consecutive_id <- function(...) {
   rleidv(data)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit consecutive_id
-consecutive_id. <- function(...) {
-  deprecate_dot_fun()
-  consecutive_id(...)
-}
