@@ -25,30 +25,27 @@
 #' df %>%
 #'   distinct(z)
 distinct <- function(.df, ..., .keep_all = FALSE) {
-  .df <- .df_as_tidytable(.df)
+  UseMethod("distinct")
+}
 
-  dots <- enquos(...)
-
-  check_across(dots, "distinct")
-
-  if (length(dots) == 0) {
-    out <- unique(.df)
+#' @export
+distinct.tidytable <- function(.df, ..., .keep_all = FALSE) {
+  if (missing(...)) {
+    out <- vec_unique(.df)
   } else {
-    cols <- tidyselect_locs(.df, ...)
+    dots <- enquos(...)
 
-    out <- unique(.df, by = cols)
+    check_no_across(dots)
 
-    if (!.keep_all) {
-      cols_keep <- unname(cols)
-      out <- select(out, any_of(cols_keep))
-    }
+    cols <- tidyselect_locs(.df, !!!dots)
 
-    .is_named <- have_name(dots)
-
-    if (any(.is_named)) {
-      named_dots <- dots[.is_named]
-
-      out <- rename(out, !!!named_dots)
+    if (.keep_all) {
+      locs <- vec_unique_loc(select(.df, any_of(cols)))
+      out <- vec_slice(.df, locs)
+      out <- rename(out, any_of(cols))
+    } else {
+      out <- select(.df, any_of(cols))
+      out <- vec_unique(out)
     }
   }
 
@@ -56,9 +53,7 @@ distinct <- function(.df, ..., .keep_all = FALSE) {
 }
 
 #' @export
-#' @keywords internal
-#' @inherit distinct
-distinct. <- function(.df, ..., .keep_all = FALSE) {
-  deprecate_dot_fun()
+distinct.data.frame <- function(.df, ..., .keep_all = FALSE) {
+  .df <- as_tidytable(.df)
   distinct(.df, ..., .keep_all = .keep_all)
 }
