@@ -23,10 +23,3 @@ expand_grid <- function(..., .name_repair = "check_unique") {
   unpack(out, .name_repair)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit expand_grid
-expand_grid. <- function(..., .name_repair = "check_unique") {
-  deprecate_dot_fun()
-  expand_grid(..., .name_repair = .name_repair)
-}
