@@ -22,28 +22,12 @@ first <- function(x, default = NULL, na_rm = FALSE) {
   nth(x, 1L, default, na_rm)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit first
-first. <- function(x, default = NULL, na_rm = FALSE) {
-  deprecate_dot_fun()
-  first(x, default, na_rm)
-}
-
 #' @export
 #' @rdname first
 last <- function(x, default = NULL, na_rm = FALSE) {
   nth(x, -1L, default, na_rm)
 }
 
-#' @export
-#' @keywords internal
-#' @inherit first
-last. <- function(x, default = NULL, na_rm = FALSE) {
-  deprecate_dot_fun()
-  last(x, default, na_rm)
-}
-
 #' @export
 #' @rdname first
 nth <- function(x, n, default = NULL, na_rm = FALSE) {
@@ -63,14 +47,6 @@ nth <- function(x, n, default = NULL, na_rm = FALSE) {
   }
 }
 
-#' @export
-#' @keywords internal
-#' @inherit first
-nth. <- function(x, n, default = NULL, na_rm = FALSE) {
-  deprecate_dot_fun()
-  nth(x, n, default, na_rm)
-}
-
 nth_default <- function(x, default) {
   if (obj_is_list(x)) {
     out <- default
