@@ -24,42 +24,47 @@
 #'   replace_na(list(x = 5, y = 0))
 replace_na <- function(.x, replace) {
   if (missing(replace)) return(.x)
-
-  if (is.data.frame(.x)) {
-    .x <- .df_as_tidytable(.x)
-
-    stopifnot(obj_is_list(replace))
-
-    keep <- names(replace) %in% names(.x)
-
-    replace <- replace[keep]
-
-    replace_vars <- names(replace)[keep]
-
-    calls <- map2(syms(replace_vars), replace,
-                  ~ call2("replace_na", .x, .y, .ns = "tidytable"))
-
-    names(calls) <- replace_vars
-
-    out <- mutate(.x, !!!calls)
-  } else {
-    if (is.numeric(.x)) {
-      out <- nafill(.x, "const", fill = replace)
-    } else {
-      out <- .x
-      missing <- vec_detect_missing(out)
-      out[missing] <- replace
-    }
-  }
-  out
+  UseMethod("replace_na")
 }
 
 #' @export
-#' @keywords internal
-#' @inherit replace_na
-replace_na. <- function(.x, replace) {
-  deprecate_dot_fun()
+replace_na.tidytable <- function(.x, replace) {
+  stopifnot(obj_is_list(replace))
+
+  keep <- names(replace) %in% names(.x)
+
+  replace <- replace[keep]
+
+  replace_vars <- names(replace)[keep]
+
+  calls <- map2(syms(replace_vars), replace,
+                ~ call2("replace_na", .x, .y, .ns = "tidytable"))
+
+  names(calls) <- replace_vars
+
+  mutate(.x, !!!calls)
+}
+
+#' @export
+replace_na.data.frame <- function(.x, replace) {
+  .x <- as_tidytable(.x)
   replace_na(.x, replace)
 }
 
+#' @export
+replace_na.numeric <- function(.x, replace) {
+  nafill(.x, "const", fill = replace)
+}
 
+#' @export
+replace_na.default <- function(.x, replace) {
+  missing <- vec_detect_missing(.x)
+  vec_assign(.x, missing, replace)
+}
+
+#' @export
+replace_na.list <- function(.x, replace) {
+  missing <- vec_detect_missing(.x)
+  .x[missing] <- replace
+  .x
+}
