@@ -9,14 +9,6 @@ test_that("ascending order works", {
   expect_equal(across_df, check_df)
 })
 
-test_that("descending order works with desc.", {
-  across_df <- arrange(test_df, across(everything(), desc.))
-
-  check_df <- arrange(test_df, -a, -b)
-
-  expect_equal(across_df, check_df)
-})
-
 test_that("descending order works with desc", {
   across_df <- arrange(test_df, across(everything(), desc))
 
@@ -33,14 +25,6 @@ test_that("descending order works with rlang lambda", {
   expect_equal(across_df, check_df)
 })
 
-test_that("works with dot", {
-  across_df <- arrange(test_df, across.())
-
-  check_df <- arrange(test_df, a, b)
-
-  expect_equal(across_df, check_df)
-})
-
 # mutate -----------------------------------------------------
 test_that(".cols selection works", {
   df <- data.table(x_start = c(1,1,1), end_x = c(2,2,2), z = c("a", "a", "b"))
